@@ -1,11 +1,12 @@
 """History manager extension for the standard Python shell and IPython"""
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 import curses
 import sys
 
-from pyhstr.application import IS_IPYTHON, main
+from pyhstr.application import main, SHELL
+from pyhstr.utilities import Shell
 
 hh = object()
 original = sys.displayhook
@@ -16,7 +17,7 @@ def spam(arg):
     else:
         original(arg)
 
-if not IS_IPYTHON:
+if SHELL != Shell.IPYTHON:
     sys.displayhook = spam
 else:
     from IPython.core.magic import register_line_magic
@@ -27,4 +28,4 @@ else:
         This line magic mirrors the behaviour of sys.displayhook
         in the regular Python shell. Use %hh to invoke.
         """
-        curses.wrapper(main)
\ No newline at end of file
+        curses.wrapper(main)
